==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QNodeCreatedChangeBase.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all NodeCreated QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html">Qt3DCore::QNodeCreatedChangeBase</a></p>
 */
public class QNodeCreatedChangeBase extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#QNodeCreatedChangeBase">Qt3DCore::QNodeCreatedChangeBase::QNodeCreatedChangeBase(const Qt3DCore::QNode*)</a></p>
     */
    @Deprecated
    public QNodeCreatedChangeBase(io.qt.qt3d.core.@Nullable QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, node);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeCreatedChangeBase instance, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#isNodeEnabled">Qt3DCore::QNodeCreatedChangeBase::isNodeEnabled()const</a></p>
     */
    @QtUninvokable
    public final boolean isNodeEnabled(){
        return isNodeEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNodeEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#metaObject">Qt3DCore::QNodeCreatedChangeBase::metaObject()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#parentId">Qt3DCore::QNodeCreatedChangeBase::parentId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId parentId(){
        return parentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId parentId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNodeCreatedChangeBase(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.19-sources.jar: io/qt/qt3d/core/QNodeCreatedChangeBase.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all NodeCreated QSceneChange events</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html">Qt3DCore::QNodeCreatedChangeBase</a></code></p>
 */
public class QNodeCreatedChangeBase extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#QNodeCreatedChangeBase">Qt3DCore::QNodeCreatedChangeBase::<wbr/>QNodeCreatedChangeBase(const Qt3DCore::QNode*)</a></code></p>
     */
    public QNodeCreatedChangeBase(io.qt.qt3d.core.@Nullable QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, node);
    }
    
    private native static void initialize_native(QNodeCreatedChangeBase instance, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#isNodeEnabled">Qt3DCore::QNodeCreatedChangeBase::<wbr/>isNodeEnabled()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isNodeEnabled(){
        return isNodeEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNodeEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#metaObject">Qt3DCore::QNodeCreatedChangeBase::<wbr/>metaObject()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecreatedchangebase.html#parentId">Qt3DCore::QNodeCreatedChangeBase::<wbr/>parentId()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId parentId(){
        return parentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId parentId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNodeCreatedChangeBase(QPrivateConstructor p) { super(p); } 
    
}
